@@ -36,7 +36,7 @@
 aal_device_t           *fs_device;
 reiser4_fs_t           *fs = NULL;
 reiser4_format_t       *format;
-char *EXECNAME = "clone.reiser4";
+char *EXECNAME = "partclone.reiser4";
 
 /// open device
 static void fs_open(char* device){
